use strict;
use warnings;
use autodie;

use Test::More tests => 14;
use Stanford::LDAP::SyncSuGAL;
use Data::Compare;
use Data::Dumper;

require 't/setup.pl';

my $S = do_setup();

my (@S1, @T1) ;

my ($A_href, $D_href);
my (%A, %D);

my @S2 = ('a');
my @S3 = ('a', 'a', 'a');
my @S4 = ('a', 'a', 'b', 'd', 'e', 'e');
my @S5 = ('a', 'a', 'b', 'c', 'c', 'c', 'd', 'e', 'e', 'h', 'h');

my @T2 = ('a');
my @T3 = ('a', 'b', 'e', 'e');
my @T4 = ('a', 'a', 'a', 'a', 'b', 'd', 'e', 'e', 'f', 'f', 'g');

# Test 1: Both empty. Should return references to empty hashes
($A_href, $D_href) = $S->calc_add_delete(\@S1, \@T1);
%A = %$A_href;
%D = %$D_href;
ok (!%A);
ok (!%D);

# Test 2: Target empty (A). Add should be ('a' => 1), delete should be empty
($A_href, $D_href) = $S->calc_add_delete(\@S2, \@T1);
%A = %$A_href;
%D = %$D_href;
ok (Compare(\%A, {'a' => 1}));
ok (!%D);

# Test 3: Target empty (B). Add should be ('a' => 3), delete should be empty
($A_href, $D_href) = $S->calc_add_delete(\@S3, \@T1);
%A = %$A_href;
%D = %$D_href;
ok (Compare(\%A, {'a' => 3}));
ok (!%D);

# Test 3: Target and source are the same. Add and delete should both be empty.
($A_href, $D_href) = $S->calc_add_delete(\@S3, \@S3);
%A = %$A_href;
%D = %$D_href;
ok (!%A);
ok (!%D);

# Test 4: Source is a superset of target. Add should be
# {'a' => 1, 'd' => 1 }, delete should be empty.
($A_href, $D_href) = $S->calc_add_delete(\@S4, \@T3);
%A = %$A_href;
%D = %$D_href;
ok (Compare(\%A, {'a' => 1, 'd' => 1 }));
ok (!%D);

# Test 5: Target is a superset of source.
# @S4 = ('a', 'a', 'b', 'd', 'e', 'e');
# @T4 = ('a', 'a', 'a', 'a', 'b', 'd', 'e', 'e', 'f', 'f', 'g');
# Add should be empty, delete should be
#   {'a' => 2, 'f' => 2, 'g' => 1}
($A_href, $D_href) = $S->calc_add_delete(\@S4, \@T4);
%A = %$A_href;
%D = %$D_href;
ok (!%A);
ok (Compare(\%D, {'a' => 2, 'f' => 2, 'g' => 1}));

# Test 6. Target and source neither subset of the other.
# @S5 = ('a', 'a', 'b', 'c', 'c', 'c', 'd', 'e', 'e', 'h', 'h');
# @T4 = ('a', 'a', 'a', 'a', 'b', 'd', 'e', 'e', 'f', 'f', 'g');
# Add:
#  {'c' => 3, 'h' => 2 }
# Delete:
#  {'a' => 2, 'f' => 2, 'g' => 1 }
($A_href, $D_href) = $S->calc_add_delete(\@S5, \@T4);
%A = %$A_href;
%D = %$D_href;
ok (Compare(\%A, {'c' => 3, 'h' => 2 }));
ok (Compare(\%D, {'a' => 2, 'f' => 2, 'g' => 1 }));






