use strict;
use warnings;
use autodie;

use Test::More tests => 8 ;
use Data::Dumper;
use Stanford::Orange::Util qw/run_command_improved/;

require 't/setup.pl';

my $S = do_setup();

my $logfile = '/tmp/testing.log';

# ### # ### # ### # ### # ### # ### # ### # ### # ### # ### # ###
sub check_log_file {
    my ($text) = @_ ;
    my @cmd = ('grep', '-P', $text, $logfile);
    my ($stdout, $stderr, $rv) = run_command_improved(@cmd);
    if ($stdout) {
        return 1 ;
    } else {
        return 0 ;
    }
}
# ### # ### # ### # ### # ### # ### # ### # ### # ### # ### # ###
# Initialize the logger with NO file.
ok($S->logger_init());

# Initialize the logger with a configuration file that logs to a file in
# /tmp.
ok($S->log4perl_config('./t/log4perl.conf'));
ok($S->logger_init());

# Log some messages and verify that they got through.
$S->log_info('message 1');
ok(check_log_file('message'));
ok(check_log_file('INFO'));
ok(!check_log_file('ZZZ'));

$S->log_warn('ABC 123');
ok(check_log_file('\d\d\d\d-\d\d-\d\dT\d\d:\d\d:\d\d.\d{6} TESTING WARN - ABC 123'));

# Read the main configuration file. Set some overrides
my %overrides = (
    'update' => 1,
    ) ;

$S->read_config({
    'config_file' => './t/main.conf',
    'overrides'   => \%overrides,
    'skip_checks' => 1,
                }
    );

my %VISIB_ATTRIBUTES = %{ $S->VISIB_ATTRIBUTES() };
ok(scalar(keys %{ $S->VISIB_ATTRIBUTES() }) > 10);

# Bind to the LDAP as a reader and writer
if (!$ENV{'DEB_PACKAGE_BUILD'}) {
    ok($S->bind_ldap_reader());
    ok($S->bind_ldap_writer());
}


# Cleanup
unlink $logfile;

