use Stanford::LDAPserver;
use Stanford::LDAP::SyncSuGAL;

# Set the DEB_PACKAGE_BUILD environment variable.
require 't/run_non_build_tests.pl' ;

sub do_setup {
    my ($logger_conf_file, $ldap_host, $krb5ccname_path) = @_;

    my $S = Stanford::LDAP::SyncSuGAL->new();

    # Initialize the logger with a configuration file that logs to a file in
    # /tmp.
    my  $log4perl_config ;
    if ($logger_conf_file) {
        $log4perl_config = $logger_conf_file;
    } else {
        $log4perl_config = './t/log4perl.conf';
    }

    # Read the main configuration file. Set some overrides.
    my %overrides = (
        'update'          => 1,
        'log4perl_config' => $logger_conf_file,
        ) ;

    $S->read_config({
        'config_file'  => './t/main.conf',
        'overrides'    => \%overrides,
        'skip_checks'  => 1,
                    }
        );

    if ($krb5ccname_path) {
        if (!(-e $krb5ccname_path)) {
            die "no file at $krb5ccname_path" ;
        }
        $ENV{'KRB5CCNAME'} = $krb5ccname_path;
        $S->use_krb5ccname(1);
    }

    if ($ldap_host) {
       $S->ldap_host($ldap_host);
    }

    my %VISIB_ATTRIBUTES = %{ $S->VISIB_ATTRIBUTES() };

    # Bind to the LDAP as a reader and writer (but not during package
    # build).
    if (!$ENV{'DEB_PACKAGE_BUILD'}) {
        $S->bind_ldap_reader();
        $S->bind_ldap_writer();
    }

    return $S;
}

1;
